==> novaideo-1.0.tar.gz: novaideo-1.0/novaideo/content/processes/novaideo_process_management/definition.py <==
# Copyright (c) 2014 by Ecreall under licence AGPL terms 
# avalaible on http://www.gnu.org/licenses/agpl.html 

# licence: AGPL
# author: Amen Souissi

from dace.processdefinition.processdef import ProcessDefinition
from dace.processdefinition.activitydef import ActivityDefinition
from dace.processdefinition.gatewaydef import (
    ExclusiveGatewayDefinition,
    ParallelGatewayDefinition)
from dace.processdefinition.transitiondef import TransitionDefinition
from dace.processdefinition.eventdef import (
    StartEventDefinition,
    EndEventDefinition)
from dace.objectofcollaboration.services.processdef_container import (
    process_definition)
from pontus.core import VisualisableElement

from .behaviors import (
    Update
    )
from novaideo import _


@process_definition(name='novaideoprocessmanagement', id='novaideoprocessmanagement')
class NovaIdeoProcessManagement(ProcessDefinition, VisualisableElement):
    isUnique = True

    def __init__(self, **kwargs):
        super(NovaIdeoProcessManagement, self).__init__(**kwargs)
        self.title = _('Process management')
        self.description = _('Process management')

    def _init_definition(self):
        self.defineNodes(
                start = StartEventDefinition(),
                pg = ParallelGatewayDefinition(),
                update = ActivityDefinition(contexts=[Update],
                                       description=_("Update processes"),
                                       title=_("update processes"),
                                       groups=[_('More')]),
                eg = ExclusiveGatewayDefinition(),
                end = EndEventDefinition(),
        )
        self.defineTransitions(
                TransitionDefinition('start', 'pg'),
                TransitionDefinition('pg', 'update'),
                TransitionDefinition('update', 'eg'),
                TransitionDefinition('eg', 'end'),

        )

==> novaideo-1.3.tar.gz: novaideo-1.3/novaideo/content/processes/novaideo_process_management/definition.py <==
# Copyright (c) 2014 by Ecreall under licence AGPL terms 
# avalaible on http://www.gnu.org/licenses/agpl.html 

# licence: AGPL
# author: Amen Souissi

from dace.processdefinition.processdef import ProcessDefinition
from dace.processdefinition.activitydef import ActivityDefinition
from dace.processdefinition.gatewaydef import (
    ExclusiveGatewayDefinition,
    ParallelGatewayDefinition)
from dace.processdefinition.transitiondef import TransitionDefinition
from dace.processdefinition.eventdef import (
    StartEventDefinition,
    EndEventDefinition)
from dace.objectofcollaboration.services.processdef_container import (
    process_definition)
from pontus.core import VisualisableElement

from .behaviors import (
    Update
    )
from novaideo import _


@process_definition(name='novaideoprocessmanagement', id='novaideoprocessmanagement')
class NovaIdeoProcessManagement(ProcessDefinition, VisualisableElement):
    isUnique = True

    def __init__(self, **kwargs):
        super(NovaIdeoProcessManagement, self).__init__(**kwargs)
        self.title = _('Process management')
        self.description = _('Process management')

    def _init_definition(self):
        self.defineNodes(
                start = StartEventDefinition(),
                pg = ParallelGatewayDefinition(),
                update = ActivityDefinition(contexts=[Update],
                                       description=_("Update processes"),
                                       title=_("Update processes"),
                                       groups=[_('More')]),
                eg = ExclusiveGatewayDefinition(),
                end = EndEventDefinition(),
        )
        self.defineTransitions(
                TransitionDefinition('start', 'pg'),
                TransitionDefinition('pg', 'update'),
                TransitionDefinition('update', 'eg'),
                TransitionDefinition('eg', 'end'),

        )
